@@ -1,12 +1,16 @@
 package Data::TUID;
-BEGIN {
-  $Data::TUID::VERSION = '0.0111_6';
-}
-# ABSTRACT: A smaller and more communicable pseudo-UUID
 
 use warnings;
 use strict;
 
+=head1 NAME
+
+Data::TUID - A smaller and more communicable pseudo-UUID
+
+=head1 VERSION
+
+Version 0.01
+
 =head1 SYNOPSIS
 
     use Data::TUID
@@ -15,31 +19,31 @@ use strict;
     $tuid = tuid length => 4    # Generate a TUID of length 4
     $tuid = Data::TUID->tuid    # Generate a TUID with the default length
 
-    $tuid = tuid uuid => '1bf4d967-9e4c-4414-9be0-26f31c16fb53' # Generate a TUID based off of the given UUID
+    $tuid = tuid uuid => '1bf4d967-9e4c-4414-9be0-26f31c16fb53' # Generate a TUID based of the give UUID
 
 A sample run (length 4):
 
-    rrry
-    ggf5
-    m1qb
-    xczx
-    pv9y
+rrry
+ggf5
+m1qb
+xczx
+pv9y
 
 A sample run (length 8):
 
-    5xcfw8nj
-    2q255fyg
-    pn3xns4k
-    1xcamd3y
-    eczzca9c
+5xcfw8nj
+2q255fyg
+pn3xns4k
+1xcamd3y
+eczzca9c
 
 A sample run (no length limit):
 
-    2kdk8wzjmfapj28cvexj6qndq7
-    2tmzr1f3k46tr813dtrxx2vhkqkd
-    1x3608c39mb1n726dhmxedjy72d
-    pre6tg2dm37zbw9amxg2c8bghn
-    3ys0kw21rmtpf54gsmnd28r99pj
+2kdk8wzjmfapj28cvexj6qndq7
+2tmzr1f3k46tr813dtrxx2vhkqkd
+1x3608c39mb1n726dhmxedjy72d
+pre6tg2dm37zbw9amxg2c8bghn
+3ys0kw21rmtpf54gsmnd28r99pj
 
 =head1 DESCRIPTION
 
@@ -49,7 +53,7 @@ C<substr>)
 
 Although I've tried to sample the UUID evenly, this technique does not give any guarantee on uniqueness. Caveat emptor.
 
-Finally, the result is more communicable (and smaller) due to the Crockford base-32 encoding. The Crockford technique
+Finally, the result is more communicable (and smaller) due to the Crockford base 32 encoding. The Crockford technique
 uses:
 
     A case-insensitive mapping
@@ -60,11 +64,11 @@ So, given a TUID (say something a user typed in for a URL), you can translate am
 
 =head1 USAGE
 
-=head2 Data::TUID->tuid( ... )
+=head1 Data::TUID->tuid( ... )
 
-=head2 Data::TUID::tuid( ... )
+=head1 Data::TUID::tuid( ... )
 
-=head2 tuid ...
+=head1 tuid ...
 
 The arguments are:
 
@@ -79,23 +83,13 @@ L<Encode::Base32::Crockford>
 
 L<Data::UUID::LibUUID>
 
-L<http://www.crockford.com/wrmg/base32.html>
-
 =cut
 
+our $VERSION = '0.01';
 use vars qw/@ISA @EXPORT/; @ISA = qw/Exporter/; @EXPORT = qw/tuid/;
 
 use Encode::Base32::Crockford qw/base32_encode/;
-
-use Data::TUID::BestUUID;
-
-sub new_uuid {
-    return Data::TUID::BestUUID->new_uuid( @_ );
-}
-
-sub uuid_to_canonical {
-    return Data::TUID::BestUUID->uuid_to_canonical( @_ );
-}
+use Data::UUID::LibUUID qw/new_uuid_binary uuid_to_binary/;
 
 sub tuid {
     shift if @_ && $_[0] eq __PACKAGE__;
@@ -107,18 +101,10 @@ sub tuid {
         %given = @_;
     }
 
-    my $uuid = $given{uuid} || new_uuid;
-    $uuid = uuid_to_canonical( $uuid );
+    my $uuid = $given{uuid} || new_uuid_binary;
+    $uuid = uuid_to_binary $uuid;
 
-    my @tuid;
-    {
-        my $uuid = $uuid;
-        $uuid =~ s/-//g;
-        my @hex = unpack( 'A8 A8 A8 A8', $uuid );
-        my @value = map { hex $_ } @hex;
-        my @base32 = map { base32_encode $_ } @value;
-        @tuid = @base32;
-    }
+    my @tuid = map { lc base32_encode $_ } unpack 'L*', new_uuid_binary;
 
     my $all;
     my $size = $given{size};
@@ -140,8 +126,60 @@ sub tuid {
     return $tuid;
 }
 
+=head1 AUTHOR
+
+Robert Krimen, C<< <rkrimen at cpan.org> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-data-tuid at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Data-TUID>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+
+
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Data::TUID
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-TUID>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Data-TUID>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Data-TUID>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Data-TUID/>
+
+=back
+
+
 =head1 ACKNOWLEDGEMENTS
 
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright 2009 Robert Krimen, all rights reserved.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+
 =cut
 
-1;
+1; # End of Data::TUID
